@@ -68,7 +68,10 @@ class RunnerInit(Init):
             help_msg=help_msg,
         )
 
-        help_msg = 'URI for listing the status server. Usually a "HOST:PORT" string'
+        help_msg = (
+            'URI where status server will listen on. Usually a "HOST:PORT" '
+            'string. This is only effective if "status_server_auto" is disabled'
+        )
         settings.register_option(
             section=section,
             key="status_server_listen",
@@ -80,7 +83,8 @@ class RunnerInit(Init):
         help_msg = (
             "URI for connecting to the status server, usually "
             'a "HOST:PORT" string. Use this if your status server '
-            "is in another host, or different port"
+            "is in another host, or different port. This is only "
+            'effective if "status_server_auto" is disabled'
         )
         settings.register_option(
             section=section,
@@ -148,46 +152,125 @@ class RunnerCLI(CLI):
             return
 
         parser = parser.add_argument_group("nrunner specific options")
+        settings.add_argparser_to_option(
+            namespace="nrunner.shuffle",
+            parser=parser,
+            long_arg="--shuffle",
+            action="store_true",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--shuffle" instead.'
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.shuffle",
             parser=parser,
             long_arg="--nrunner-shuffle",
             action="store_true",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
+        settings.add_argparser_to_option(
+            namespace="nrunner.status_server_auto",
+            parser=parser,
+            long_arg="--status-server-disable-auto",
+            action="store_false",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--status-server-disable-auto '
+            "instead."
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.status_server_auto",
             parser=parser,
             long_arg="--nrunner-status-server-disable-auto",
             action="store_false",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
+        settings.add_argparser_to_option(
+            namespace="nrunner.status_server_listen",
+            parser=parser,
+            long_arg="--status-server-listen",
+            metavar="HOST_PORT",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--status-server-listen" instead.'
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.status_server_listen",
             parser=parser,
             long_arg="--nrunner-status-server-listen",
             metavar="HOST_PORT",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
+        settings.add_argparser_to_option(
+            namespace="nrunner.status_server_uri",
+            parser=parser,
+            long_arg="--status-server-uri",
+            metavar="HOST_PORT",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--status-server-uri" instead.'
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.status_server_uri",
             parser=parser,
             long_arg="--nrunner-status-server-uri",
             metavar="HOST_PORT",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
+        settings.add_argparser_to_option(
+            namespace="nrunner.max_parallel_tasks",
+            parser=parser,
+            long_arg="--max-parallel-tasks",
+            metavar="NUMBER_OF_TASKS",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--max-parallel-tasks" instead.'
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.max_parallel_tasks",
             parser=parser,
             long_arg="--nrunner-max-parallel-tasks",
             metavar="NUMBER_OF_TASKS",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
+        settings.add_argparser_to_option(
+            namespace="nrunner.spawner",
+            parser=parser,
+            long_arg="--spawner",
+            metavar="SPAWNER",
+        )
+
+        help_msg = (
+            "This option is currently DEPRECATED and will not be available "
+            'on Avocado 100.0 and later.  Please use "--spawner" instead.'
+        )
         settings.add_argparser_to_option(
             namespace="nrunner.spawner",
             parser=parser,
             long_arg="--nrunner-spawner",
             metavar="SPAWNER",
+            help_msg=help_msg,
+            allow_multiple=True,
         )
 
     def run(self, config):
@@ -199,6 +282,10 @@ class Runner(RunnerInterface):
     name = "nrunner"
     description = "nrunner based implementation of job compliant runner"
 
+    def __init__(self):
+        super().__init__()
+        self.status_server_dir = None
+
     @staticmethod
     def _update_avocado_configuration_used_on_runnables(runnables, config):
         """Updates the config used on runnables with this suite's config values
@@ -211,18 +298,21 @@ class Runner(RunnerInterface):
         for runnable in runnables:
             runnable.config = Runnable.filter_runnable_config(runnable.kind, config)
 
-    def _determine_status_server_uri(self, test_suite):
-        # pylint: disable=W0201
-        self.status_server_dir = None
+    def _determine_status_server(self, test_suite, config_key):
         if test_suite.config.get("nrunner.status_server_auto"):
             # no UNIX domain sockets on Windows
             if platform.system() != "Windows":
-                self.status_server_dir = tempfile.TemporaryDirectory(prefix="avocado_")
+                if self.status_server_dir is None:
+                    self.status_server_dir = tempfile.TemporaryDirectory(
+                        prefix="avocado_"
+                    )
                 return os.path.join(self.status_server_dir.name, ".status_server.sock")
-        return test_suite.config.get("nrunner.status_server_listen")
+        return test_suite.config.get(config_key)
 
     def _create_status_server(self, test_suite, job):
-        listen = self._determine_status_server_uri(test_suite)
+        listen = self._determine_status_server(
+            test_suite, "nrunner.status_server_listen"
+        )
         # pylint: disable=W0201
         self.status_repo = StatusRepo(job.unique_id)
         # pylint: disable=W0201
@@ -282,7 +372,7 @@ class Runner(RunnerInterface):
         graph = RuntimeTaskGraph(
             test_suite.get_test_variants(),
             test_suite.name,
-            self.status_server.uri,
+            self._determine_status_server(test_suite, "nrunner.status_server_uri"),
             job.unique_id,
         )
         # pylint: disable=W0201
