@@ -18,7 +18,7 @@ else:
     HAS_YUM_MODULE = True
 
 
-log = logging.getLogger('avocado.utils.software_manager')
+log = logging.getLogger("avocado.utils.software_manager")
 
 
 class YumBackend(RpmBackend):
@@ -32,15 +32,15 @@ class YumBackend(RpmBackend):
     """
 
     #: Path to the repository managed by Avocado
-    REPO_FILE_PATH = '/etc/yum.repos.d/avocado-managed.repo'
+    REPO_FILE_PATH = "/etc/yum.repos.d/avocado-managed.repo"
 
-    def __init__(self, cmd='yum'):
+    def __init__(self, cmd="yum"):
         """
         Initializes the base command and the yum package repository.
         """
         super().__init__()
         self.cmd = cmd
-        self.base_command = f'{utils_path.find_command(cmd)} -y '
+        self.base_command = f"{utils_path.find_command(cmd)} -y "
         self._cfgparser = None
         self._set_version(cmd)
         self._yum_base = None
@@ -58,9 +58,13 @@ class YumBackend(RpmBackend):
             if HAS_YUM_MODULE:
                 self._yum_base = yum.YumBase()
             else:
-                log.debug("%s module for Python is required to use the "
-                          "'provides' command. Using the basic support "
-                          "from rpm and %s commands", self.cmd, self.cmd)
+                log.debug(
+                    "%s module for Python is required to use the "
+                    "'provides' command. Using the basic support "
+                    "from rpm and %s commands",
+                    self.cmd,
+                    self.cmd,
+                )
         return self._yum_base
 
     @staticmethod
@@ -71,22 +75,22 @@ class YumBackend(RpmBackend):
         process.system("yum clean all", sudo=True)
 
     def _set_version(self, cmd):
-        result = process.run(self.base_command + '--version',
-                             verbose=False,
-                             ignore_status=True)
+        result = process.run(
+            self.base_command + "--version", verbose=False, ignore_status=True
+        )
         first_line = result.stdout_text.splitlines()[0].strip()
         try:
-            ver = re.findall(r'\d*.\d*.\d*', first_line)[0]
+            ver = re.findall(r"\d*.\d*.\d*", first_line)[0]
         except IndexError:
             ver = first_line
         self.pm_version = ver
-        log.debug('%s version: %s', cmd, self.pm_version)
+        log.debug("%s version: %s", cmd, self.pm_version)
 
     def install(self, name):
         """
         Installs package [name]. Handles local installs.
         """
-        i_cmd = self.base_command + 'install' + ' ' + name
+        i_cmd = self.base_command + "install" + " " + name
 
         try:
             process.system(i_cmd, sudo=True)
@@ -100,7 +104,7 @@ class YumBackend(RpmBackend):
 
         :param name: Package name (eg. 'ipython').
         """
-        r_cmd = self.base_command + 'erase' + ' ' + name
+        r_cmd = self.base_command + "erase" + " " + name
         try:
             process.system(r_cmd, sudo=True)
             return True
@@ -116,28 +120,28 @@ class YumBackend(RpmBackend):
         # Check if we URL is already set
         for section in self.repo_config_parser.sections():
             for option, value in self.repo_config_parser.items(section):
-                if option == 'url' and value == url:
+                if option == "url" and value == url:
                     return True
 
         # Didn't find it, let's set it up
         while True:
-            section_name = 'software_manager' + '_'
+            section_name = "software_manager" + "_"
             section_name += data_factory.generate_random_string(4)
             if not self.repo_config_parser.has_section(section_name):
                 break
         try:
             self.repo_config_parser.add_section(section_name)
-            self.repo_config_parser.set(section_name, 'name',
-                                        'Avocado managed repository')
-            self.repo_config_parser.set(section_name, 'url', url)
-            self.repo_config_parser.set(section_name, 'enabled', '1')
-            self.repo_config_parser.set(section_name, 'gpgcheck', '0')
-            prefix = 'avocado_software_manager'
+            self.repo_config_parser.set(
+                section_name, "name", "Avocado managed repository"
+            )
+            self.repo_config_parser.set(section_name, "url", url)
+            self.repo_config_parser.set(section_name, "enabled", "1")
+            self.repo_config_parser.set(section_name, "gpgcheck", "0")
+            prefix = "avocado_software_manager"
             with tempfile.NamedTemporaryFile("w", prefix=prefix) as tmp_file:
                 self.repo_config_parser.write(tmp_file)
-                tmp_file.flush()    # Sync the content
-                process.system(f'cp {tmp_file.name} {self.REPO_FILE_PATH}',
-                               sudo=True)
+                tmp_file.flush()  # Sync the content
+                process.system(f"cp {tmp_file.name} {self.REPO_FILE_PATH}", sudo=True)
             return True
         except (OSError, process.CmdError) as details:
             log.error(details)
@@ -150,16 +154,15 @@ class YumBackend(RpmBackend):
         :param url: Universal Resource Locator of the repository.
         """
         try:
-            prefix = 'avocado_software_manager'
+            prefix = "avocado_software_manager"
             with tempfile.NamedTemporaryFile("w", prefix=prefix) as tmp_file:
                 for section in self.repo_config_parser.sections():
                     for option, value in self.repo_config_parser.items(section):
-                        if option == 'url' and value == url:
+                        if option == "url" and value == url:
                             self.repo_config_parser.remove_section(section)
                 self.repo_config_parser.write(tmp_file.file)
-                tmp_file.flush()    # Sync the content
-                process.system(f'cp {tmp_file.name} {self.REPO_FILE_PATH}',
-                               sudo=True)
+                tmp_file.flush()  # Sync the content
+                process.system(f"cp {tmp_file.name} {self.REPO_FILE_PATH}", sudo=True)
                 return True
         except (OSError, process.CmdError) as details:
             log.error(details)
@@ -175,9 +178,9 @@ class YumBackend(RpmBackend):
         :type name: str
         """
         if not name:
-            r_cmd = self.base_command + 'update'
+            r_cmd = self.base_command + "update"
         else:
-            r_cmd = self.base_command + 'update' + ' ' + name
+            r_cmd = self.base_command + "update" + " " + name
 
         try:
             process.system(r_cmd, sudo=True)
@@ -192,16 +195,18 @@ class YumBackend(RpmBackend):
         :param name: Capability name (eg, 'foo').
         """
         if self.yum_base is None:
-            log.error("The method 'provides' is disabled, "
-                      "%s module is required for this operation", self.cmd)
+            log.error(
+                "The method 'provides' is disabled, "
+                "%s module is required for this operation",
+                self.cmd,
+            )
             return None
         try:
             # Python API need to be passed globs along with name for searching
             # all possible occurrences of pattern 'name'
-            d_provides = self.yum_base.searchPackageProvides(args=['*/' + name])
+            d_provides = self.yum_base.searchPackageProvides(args=["*/" + name])
         except Exception as exc:  # pylint: disable=W0703
-            log.error("Error searching for package that "
-                      "provides %s: %s", name, exc)
+            log.error("Error searching for package that " "provides %s: %s", name, exc)
             d_provides = []
 
         provides_list = [key for key in d_provides]
@@ -221,7 +226,7 @@ class YumBackend(RpmBackend):
         """
 
         try:
-            process.system(f'yum-builddep -y --tolerant {name}', sudo=True)
+            process.system(f"yum-builddep -y --tolerant {name}", sudo=True)
             return True
         except process.CmdError as details:
             log.error(details)
@@ -237,7 +242,7 @@ class YumBackend(RpmBackend):
 
         :return final_dir: path of ready-to-build directory
         """
-        path = tempfile.mkdtemp(prefix='avocado_software_manager')
+        path = tempfile.mkdtemp(prefix="avocado_software_manager")
         try:
             if dest_path is None:
                 log.error("Please provide a valid path")
@@ -245,23 +250,30 @@ class YumBackend(RpmBackend):
             for pkg in ["rpm-build", "yum-utils"]:
                 if not self.check_installed(pkg):
                     if not self.install(pkg):
-                        log.error("SoftwareManager (YumBackend) can't get "
-                                  "packageswith dependency resolution: Package"
-                                  " '%s' could not be installed", pkg)
+                        log.error(
+                            "SoftwareManager (YumBackend) can't get "
+                            "packageswith dependency resolution: Package"
+                            " '%s' could not be installed",
+                            pkg,
+                        )
                         return ""
             try:
-                process.run(f'yumdownloader --assumeyes --verbose '
-                            f'--source {name} --destdir {path}')
-                src_rpms = [_ for _ in next(os.walk(path))[2]
-                            if _.endswith(".src.rpm")]
+                process.run(
+                    f"yumdownloader --assumeyes --verbose "
+                    f"--source {name} --destdir {path}"
+                )
+                src_rpms = [_ for _ in next(os.walk(path))[2] if _.endswith(".src.rpm")]
                 if len(src_rpms) != 1:
-                    log.error("Failed to get downloaded src.rpm from %s:\n%s",
-                              path, next(os.walk(path))[2])
+                    log.error(
+                        "Failed to get downloaded src.rpm from %s:\n%s",
+                        path,
+                        next(os.walk(path))[2],
+                    )
                     return ""
                 if self.rpm_install(os.path.join(path, src_rpms[-1])):
-                    spec_path = os.path.join(os.environ['HOME'],
-                                             "rpmbuild", "SPECS",
-                                             f"{name}.spec")
+                    spec_path = os.path.join(
+                        os.environ["HOME"], "rpmbuild", "SPECS", f"{name}.spec"
+                    )
                     if self.build_dep(spec_path):
                         return self.prepare_source(spec_path, dest_path)
                     else:
