@@ -5,29 +5,30 @@ from avocado.utils import archive, build, process
 
 
 class Hello(Test):
-
     def setUp(self):
         tarball_locations = [
-            'https://mirrors.peers.community/mirrors/gnu/hello/hello-2.9.tar.gz',
-            'https://mirrors.kernel.org/gnu/hello/hello-2.9.tar.gz',
-            'http://gnu.c3sl.ufpr.br/ftp/hello-2.9.tar.gz',
-            'ftp://ftp.funet.fi/pub/gnu/prep/hello/hello-2.9.tar.gz'
-            ]
+            "https://mirrors.peers.community/mirrors/gnu/hello/hello-2.9.tar.gz",
+            "https://mirrors.kernel.org/gnu/hello/hello-2.9.tar.gz",
+            "http://gnu.c3sl.ufpr.br/ftp/hello-2.9.tar.gz",
+            "ftp://ftp.funet.fi/pub/gnu/prep/hello/hello-2.9.tar.gz",
+        ]
         self.hello = self.fetch_asset(
-            name='hello-2.9.tar.gz',
-            asset_hash='cb0470b0e8f4f7768338f5c5cfe1688c90fbbc74',
-            locations=tarball_locations)
+            name="hello-2.9.tar.gz",
+            asset_hash="cb0470b0e8f4f7768338f5c5cfe1688c90fbbc74",
+            locations=tarball_locations,
+        )
 
         sig_locations = [
-            'https://mirrors.peers.community/mirrors/gnu/hello/hello-2.9.tar.gz.sig',
-            'https://mirrors.kernel.org/gnu/hello/hello-2.9.tar.gz.sig',
-            'http://gnu.c3sl.ufpr.br/ftp/hello-2.9.tar.gz.sig',
-            'ftp://ftp.funet.fi/pub/gnu/prep/hello/hello-2.9.tar.gz.sig'
-            ]
+            "https://mirrors.peers.community/mirrors/gnu/hello/hello-2.9.tar.gz.sig",
+            "https://mirrors.kernel.org/gnu/hello/hello-2.9.tar.gz.sig",
+            "http://gnu.c3sl.ufpr.br/ftp/hello-2.9.tar.gz.sig",
+            "ftp://ftp.funet.fi/pub/gnu/prep/hello/hello-2.9.tar.gz.sig",
+        ]
         self.hello_sig = self.fetch_asset(
-            name='hello-2.9.tar.gz.sig',
-            asset_hash='f3b9fae20c35740004ae7b8de1301836dab4ac30',
-            locations=sig_locations)
+            name="hello-2.9.tar.gz.sig",
+            asset_hash="f3b9fae20c35740004ae7b8de1301836dab4ac30",
+            locations=sig_locations,
+        )
 
     @fail_on(process.CmdError)
     def test_gpg_signature(self):
@@ -43,8 +44,8 @@ class Hello(Test):
 
     @fail_on(process.CmdError)
     def test_build_run(self):
-        hello_src = os.path.join(self.workdir, 'hello-2.9')
+        hello_src = os.path.join(self.workdir, "hello-2.9")
         archive.uncompress(self.hello, self.workdir)
         build.configure(hello_src)
         build.make(hello_src)
-        process.run(os.path.join(hello_src, 'src', 'hello'))
+        process.run(os.path.join(hello_src, "src", "hello"))
