@@ -8,10 +8,10 @@ class Phases(Test):
     """
 
     def setUp(self):
-        self.assertEqual(self.phase, 'SETUP')
+        self.assertEqual(self.phase, "SETUP")
 
     def test(self):
-        self.assertEqual(self.phase, 'TEST')
+        self.assertEqual(self.phase, "TEST")
 
     def tearDown(self):
-        self.assertEqual(self.phase, 'TEARDOWN')
+        self.assertEqual(self.phase, "TEARDOWN")
