@@ -15,4 +15,6 @@ class WhiteBoard(Test):
         """
         This should write a message to the whiteboard.
         """
-        self.whiteboard = base64.encodebytes(b'My message encoded in base64').decode('ascii')
+        self.whiteboard = base64.encodebytes(b"My message encoded in base64").decode(
+            "ascii"
+        )
