@@ -15,20 +15,23 @@ from avocado.plugins.spawners.process import ProcessSpawner as Spawner
 
 
 class StateMachine(TestCase):
-
     async def test(self):
         number_of_tasks = 80
         number_of_workers = 8
 
         runnable = Runnable("noop", "noop")
-        runtime_tasks = [RuntimeTask(Task(runnable, "%03i" % _))  # pylint: disable=C0209
-                         for _ in range(1, number_of_tasks + 1)]
+        runtime_tasks = [
+            RuntimeTask(Task(runnable, "%03i" % _))  # pylint: disable=C0209
+            for _ in range(1, number_of_tasks + 1)
+        ]
         spawner = Spawner()
         status_repo = StatusRepo()
 
         state_machine = statemachine.TaskStateMachine(runtime_tasks, status_repo)
-        workers = [statemachine.Worker(state_machine, spawner).run()
-                   for _ in range(number_of_workers)]
+        workers = [
+            statemachine.Worker(state_machine, spawner).run()
+            for _ in range(number_of_workers)
+        ]
 
         await asyncio.gather(*workers)
         self.assertEqual(number_of_tasks, len(state_machine.finished))
